import { Component, ViewEncapsulation, Input, ElementRef, Renderer2, HostBinding, Output, EventEmitter } from '@angular/core';
import { TagAnimation } from '../core/animation/tag-animations';
var NzTagComponent = (function () {
    function NzTagComponent(_elementRef, _render) {
        this._elementRef = _elementRef;
        this._render = _render;
        this._prefixCls = 'ant-tag';
        this._closed = false;
        /** Whether tag is closable */
        this.nzClosable = false;
        /** Event: emit before close */
        this.nzBeforeClose = new EventEmitter();
        /** Event: emit after close */
        this.nzClose = new EventEmitter();
    }
    Object.defineProperty(NzTagComponent.prototype, "_dataShow", {
        get: function () {
            return !this._closed;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzTagComponent.prototype, "_backgroundColor", {
        get: function () {
            var isPresetColor = this._isPresetColor(this.nzColor);
            return (this.nzColor && !isPresetColor) ? this.nzColor : null;
        },
        enumerable: true,
        configurable: true
    });
    NzTagComponent.prototype._afterClose = function (event) {
        if (this._closed) {
            this.nzClose.emit(event);
        }
    };
    Object.defineProperty(NzTagComponent.prototype, "_tagCls", {
        get: function () {
            var isPresetColor = this._isPresetColor(this.nzColor);
            return _a = {},
                _a[this._prefixCls] = true,
                _a[this._prefixCls + "-" + this.nzColor] = isPresetColor,
                _a[this._prefixCls + "-has-color"] = (this.nzColor && !isPresetColor),
                _a;
            var _a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzTagComponent.prototype, "_textClass", {
        get: function () {
            return this._prefixCls + "-text";
        },
        enumerable: true,
        configurable: true
    });
    NzTagComponent.prototype._close = function (event) {
        this.nzBeforeClose.emit(event);
        if (event.defaultPrevented) {
            return;
        }
        this._closed = true;
    };
    NzTagComponent.prototype._isPresetColor = function (color) {
        return /^(pink|red|yellow|orange|cyan|green|blue|purple)(-inverse)?$/.test(color);
    };
    NzTagComponent.prototype.ngOnInit = function () {
    };
    NzTagComponent.prototype.ngAfterViewInit = function () {
        this._render.addClass(this._elementRef.nativeElement, this._prefixCls + "-root");
    };
    return NzTagComponent;
}());
export { NzTagComponent };
NzTagComponent.decorators = [
    { type: Component, args: [{
                selector: 'nz-tag',
                encapsulation: ViewEncapsulation.None,
                animations: [
                    TagAnimation
                ],
                template: "\n    <span *ngIf=\"!_closed\"\n      [ngClass]=\"_tagCls\"\n      [style.backgroundColor]=\"_backgroundColor\"\n      [@tagAnimation]\n      (@tagAnimation.done)=\"_afterClose($event)\">\n      <span [class]=\"_textClass\"><ng-content></ng-content></span>\n      <i class=\"anticon anticon-cross\" (click)=\"_close($event)\" *ngIf=\"nzClosable\"></i>\n    </span>\n  ",
                styles: [
                    "/* stylelint-disable at-rule-empty-line-before,at-rule-name-space-after,at-rule-no-unknown */\n/* stylelint-disable declaration-bang-space-before */\n/* stylelint-disable declaration-bang-space-before */\n.ant-tag {\n  display: inline-block;\n  line-height: 20px;\n  height: 22px;\n  padding: 0 8px;\n  border-radius: 4px;\n  border: 1px solid #e9e9e9;\n  background: #f3f3f3;\n  font-size: 12px;\n  transition: all 0.3s cubic-bezier(0.78, 0.14, 0.15, 0.86);\n  opacity: 1;\n  margin-right: 8px;\n  cursor: pointer;\n  white-space: nowrap;\n}\n.ant-tag:hover {\n  opacity: 0.85;\n}\n.ant-tag,\n.ant-tag a,\n.ant-tag a:hover {\n  color: rgba(0, 0, 0, 0.65);\n}\n.ant-tag-text a:first-child:last-child {\n  display: inline-block;\n  margin: 0 -8px;\n  padding: 0 8px;\n}\n.ant-tag .anticon-cross {\n  display: inline-block;\n  font-size: 12px;\n  font-size: 10px 9;\n  transform: scale(0.83333333) rotate(0deg);\n  /* IE6-IE8 */\n  -ms-filter: \"progid:DXImageTransform.Microsoft.Matrix(sizingMethod='auto expand', M11=1, M12=0, M21=0, M22=1)\";\n  zoom: 1;\n  cursor: pointer;\n  font-weight: bold;\n  margin-left: 3px;\n  transition: all 0.3s ease;\n  opacity: 0.66;\n}\n:root .ant-tag .anticon-cross {\n  filter: none;\n}\n:root .ant-tag .anticon-cross {\n  font-size: 12px;\n}\n.ant-tag .anticon-cross:hover {\n  opacity: 1;\n}\n.ant-tag-has-color {\n  border-color: transparent;\n}\n.ant-tag-has-color,\n.ant-tag-has-color a,\n.ant-tag-has-color a:hover,\n.ant-tag-has-color .anticon-cross,\n.ant-tag-has-color .anticon-cross:hover {\n  color: #fff;\n}\n.ant-tag-checkable {\n  background-color: transparent;\n  border-color: transparent;\n}\n.ant-tag-checkable:not(.ant-tag-checkable-checked):hover {\n  color: #108ee9;\n}\n.ant-tag-checkable:active,\n.ant-tag-checkable-checked {\n  color: #fff;\n}\n.ant-tag-checkable-checked {\n  background-color: #108ee9;\n}\n.ant-tag-checkable:active {\n  background-color: #0e77ca;\n}\n.ant-tag-close {\n  width: 0 !important;\n  padding: 0;\n  margin: 0;\n}\n.ant-tag-zoom-enter,\n.ant-tag-zoom-appear {\n  animation: antFadeIn 0.2s cubic-bezier(0.78, 0.14, 0.15, 0.86);\n  animation-fill-mode: both;\n}\n.ant-tag-zoom-leave {\n  animation: antZoomOut 0.3s cubic-bezier(0.78, 0.14, 0.15, 0.86);\n  animation-fill-mode: both;\n}\n.ant-tag-pink {\n  color: #f5317f;\n  background: #fdd8e7;\n  border-color: #fdd8e7;\n}\n.ant-tag-pink-inverse {\n  background: #f5317f;\n  border-color: #f5317f;\n  color: #fff;\n}\n.ant-tag-red {\n  color: #f04134;\n  background: #fcdbd9;\n  border-color: #fcdbd9;\n}\n.ant-tag-red-inverse {\n  background: #f04134;\n  border-color: #f04134;\n  color: #fff;\n}\n.ant-tag-orange {\n  color: #f56a00;\n  background: #fde3cf;\n  border-color: #fde3cf;\n}\n.ant-tag-orange-inverse {\n  background: #f56a00;\n  border-color: #f56a00;\n  color: #fff;\n}\n.ant-tag-yellow {\n  color: #ffbf00;\n  background: #fff3cf;\n  border-color: #fff3cf;\n}\n.ant-tag-yellow-inverse {\n  background: #ffbf00;\n  border-color: #ffbf00;\n  color: #fff;\n}\n.ant-tag-cyan {\n  color: #00a2ae;\n  background: #cfedf0;\n  border-color: #cfedf0;\n}\n.ant-tag-cyan-inverse {\n  background: #00a2ae;\n  border-color: #00a2ae;\n  color: #fff;\n}\n.ant-tag-green {\n  color: #00a854;\n  background: #cfefdf;\n  border-color: #cfefdf;\n}\n.ant-tag-green-inverse {\n  background: #00a854;\n  border-color: #00a854;\n  color: #fff;\n}\n.ant-tag-blue {\n  color: #108ee9;\n  background: #d2eafb;\n  border-color: #d2eafb;\n}\n.ant-tag-blue-inverse {\n  background: #108ee9;\n  border-color: #108ee9;\n  color: #fff;\n}\n.ant-tag-purple {\n  color: #7265e6;\n  background: #e4e2fa;\n  border-color: #e4e2fa;\n}\n.ant-tag-purple-inverse {\n  background: #7265e6;\n  border-color: #7265e6;\n  color: #fff;\n}\n",
                    "/* stylelint-disable at-rule-empty-line-before,at-rule-name-space-after,at-rule-no-unknown */\n/* stylelint-disable declaration-bang-space-before */\n/* stylelint-disable declaration-bang-space-before */\n.ant-tag-root {\n  display: inline-block;\n}\n"
                ]
            },] },
];
/** @nocollapse */
NzTagComponent.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer2, },
]; };
NzTagComponent.propDecorators = {
    'nzClosable': [{ type: Input },],
    'nzColor': [{ type: Input },],
    'nzBeforeClose': [{ type: Output },],
    'nzClose': [{ type: Output },],
    '_dataShow': [{ type: HostBinding, args: ['attr.data-show',] },],
};
