import { Component, ViewEncapsulation, ChangeDetectorRef, Input, ViewChild, forwardRef } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import * as moment from 'moment';
import { DropDownAnimation } from '../core/animation/dropdown-animations';
var NzTimePickerInnerComponent = (function () {
    function NzTimePickerInnerComponent(_cdr) {
        this._cdr = _cdr;
        this._now = new Date();
        this._open = false;
        this._hourList = [];
        this._minuteList = [];
        this._secondList = [];
        this._value = null;
        this._selectedHour = moment(this._now).hours();
        this._selectedMinute = moment(this._now).minutes();
        this._selectedSecond = moment(this._now).seconds();
        this._format = 'HH:mm:ss';
        this._showHour = this._format.indexOf('HH') > -1;
        this._showMinute = this._format.indexOf('mm') > -1;
        this._showSecond = this._format.indexOf('ss') > -1;
        this._width = (+this._showHour + +this._showMinute + +this._showSecond) * 56 + 1 + 'px';
        this._hideDisabledOptions = false;
        // ngModel Access
        this.onChange = Function.prototype;
        this.onTouched = Function.prototype;
        this.nzPlaceHolder = '请选择时间';
        this.nzSize = 'default';
        this.nzDisabled = false;
    }
    Object.defineProperty(NzTimePickerInnerComponent.prototype, "nzHideDisabledOptions", {
        get: function () {
            return this._hideDisabledOptions;
        },
        set: function (value) {
            if (value === '') {
                this._hideDisabledOptions = true;
            }
            else {
                this._hideDisabledOptions = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzTimePickerInnerComponent.prototype, "nzFormat", {
        get: function () {
            return this._format;
        },
        set: function (value) {
            this._format = value;
            this._showHour = this._format.indexOf('HH') > -1;
            this._showMinute = this._format.indexOf('mm') > -1;
            this._showSecond = this._format.indexOf('ss') > -1;
            this._width = (+this._showHour + +this._showMinute + +this._showSecond) * 56 + 1 + 'px';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NzTimePickerInnerComponent.prototype, "nzValue", {
        get: function () {
            return this._value || this._now;
        },
        set: function (value) {
            if (this._value === value) {
                return;
            }
            this._value = value;
            this._selectedHour = moment(this.nzValue).hours();
            this._selectedMinute = moment(this.nzValue).minutes();
            this._selectedSecond = moment(this.nzValue).seconds();
        },
        enumerable: true,
        configurable: true
    });
    ;
    ;
    NzTimePickerInnerComponent.prototype._scrollToSelected = function (instance, index, duration, unit) {
        if (duration === void 0) { duration = 0; }
        var _transIndex = this._translateIndex(index, unit);
        var currentOption = instance.children[0].children[_transIndex] || instance.children[0].children[0];
        this.scrollTo(instance, currentOption.offsetTop, duration);
    };
    // got from rc-timepicker
    NzTimePickerInnerComponent.prototype.scrollTo = function (element, to, duration) {
        var _this = this;
        var requestAnimationFrame = window.requestAnimationFrame || function requestAnimationFrameTimeout() {
            return setTimeout(arguments[0], 10);
        };
        if (duration <= 0) {
            element.scrollTop = to;
            return;
        }
        var difference = to - element.scrollTop;
        var perTick = difference / duration * 10;
        requestAnimationFrame(function () {
            element.scrollTop = element.scrollTop + perTick;
            if (element.scrollTop === to) {
                return;
            }
            _this.scrollTo(element, to, duration - 10);
        });
    };
    ;
    NzTimePickerInnerComponent.prototype._selectHour = function (instance, index, disabled) {
        if (disabled) {
            return;
        }
        this._scrollToSelected(instance, index, 120, 'hour');
        this._selectedHour = index;
        this.nzValue = moment(this.nzValue).hour(index).toDate();
        this.onChange(this._value);
        this._buildMinutes();
        this._buildSeconds();
    };
    NzTimePickerInnerComponent.prototype._selectMinute = function (instance, index, disabled) {
        if (disabled) {
            return;
        }
        this._scrollToSelected(instance, index, 120, 'minute');
        this._selectedMinute = index;
        this.nzValue = moment(this.nzValue).minute(index).toDate();
        this.onChange(this._value);
        this._buildSeconds();
    };
    NzTimePickerInnerComponent.prototype._selectSecond = function (instance, index, disabled) {
        if (disabled) {
            return;
        }
        this._scrollToSelected(instance, index, 120, 'second');
        this._selectedSecond = index;
        this.nzValue = moment(this.nzValue).second(index).toDate();
        this.onChange(this._value);
    };
    NzTimePickerInnerComponent.prototype._translateIndex = function (index, unit) {
        if (!this.nzHideDisabledOptions) {
            return index;
        }
        if (unit === 'hour') {
            var disabledHours = this.nzDisabledHours && this.nzDisabledHours();
            return this._calcIndex(disabledHours, index);
        }
        else if (unit === 'minute') {
            var disabledMinutes = this.nzDisabledMinutes && this.nzDisabledMinutes(this._selectedHour);
            return this._calcIndex(disabledMinutes, index);
        }
        else if (unit === 'second') {
            var disabledSeconds = this.nzDisabledSeconds && this.nzDisabledSeconds(this._selectedHour, this._selectedMinute);
            return this._calcIndex(disabledSeconds, index);
        }
    };
    NzTimePickerInnerComponent.prototype._calcIndex = function (array, index) {
        if (array && array.length) {
            return index - array.reduce(function (pre, value) {
                return pre + (value < index ? 1 : 0);
            }, 0);
        }
        else {
            return index;
        }
    };
    NzTimePickerInnerComponent.prototype._initPosition = function () {
        this._selectedHour = moment(this.nzValue).hours();
        this._selectedMinute = moment(this.nzValue).minutes();
        this._selectedSecond = moment(this.nzValue).seconds();
        if (this._showHour) {
            this._scrollToSelected(this._hourListInstance.nativeElement, this._selectedHour, 0, 'hour');
        }
        if (this._showMinute) {
            this._scrollToSelected(this._minuteListInstance.nativeElement, this._selectedMinute, 0, 'minute');
        }
        if (this._showSecond) {
            this._scrollToSelected(this._secondListInstance.nativeElement, this._selectedSecond, 0, 'second');
        }
    };
    NzTimePickerInnerComponent.prototype._buildTime = function () {
        this._buildHours();
        this._buildMinutes();
        this._buildSeconds();
    };
    NzTimePickerInnerComponent.prototype._buildHours = function () {
        this._hourList = [];
        for (var i = 0; i <= 23; i++) {
            this._hourList.push({
                disabled: this.nzDisabledHours && (this.nzDisabledHours().indexOf(i) !== -1),
                name: i.toString().length === 1 ? ('0' + i) : ('' + i),
                index: i
            });
        }
    };
    NzTimePickerInnerComponent.prototype._buildMinutes = function () {
        this._minuteList = [];
        for (var i = 0; i <= 59; i++) {
            this._minuteList.push({
                disabled: this.nzDisabledMinutes && (this.nzDisabledMinutes(this._selectedHour).indexOf(i) !== -1),
                name: i.toString().length === 1 ? ('0' + i) : ('' + i),
                index: i
            });
        }
    };
    NzTimePickerInnerComponent.prototype._buildSeconds = function () {
        this._secondList = [];
        for (var i = 0; i <= 59; i++) {
            this._secondList.push({
                disabled: this.nzDisabledSeconds && (this.nzDisabledSeconds(this._selectedHour, this._selectedMinute).indexOf(i) !== -1),
                name: i.toString().length === 1 ? ('0' + i) : ('' + i),
                index: i
            });
        }
    };
    NzTimePickerInnerComponent.prototype.writeValue = function (value) {
        this.nzValue = value;
    };
    NzTimePickerInnerComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    NzTimePickerInnerComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    NzTimePickerInnerComponent.prototype.ngOnInit = function () {
        this._buildTime();
    };
    return NzTimePickerInnerComponent;
}());
export { NzTimePickerInnerComponent };
NzTimePickerInnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'nz-timepicker-inner',
                encapsulation: ViewEncapsulation.None,
                template: "\n    <span\n      class=\"ant-calendar-time-picker\"\n      [ngClass]=\"{'ant-time-picker-large':nzSize=='large','ant-time-picker-small':nzSize=='small'}\">\n      <div\n        class=\"ant-calendar-time-picker-panel\"\n        [@dropDownAnimation]=\"'bottom'\">\n        <div class=\"ant-calendar-time-picker-inner\"\n          [class.ant-calendar-time-picker-column-3]=\"_showHour&&_showMinute&&_showSecond\"\n          [class.ant-calendar-time-picker-column-2]=\"_showHour&&_showMinute&&!_showSecond\"\n          [class.ant-calendar-time-picker-column-1]=\"_showHour&&(!_showMinute)&&(!_showSecond)\">\n        <div class=\"ant-calendar-time-picker-combobox\">\n          <div\n            class=\"ant-calendar-time-picker-select\"\n            #hourListInstance\n            *ngIf=\"_showHour\">\n            <ul>\n              <ng-template\n                ngFor\n                let-_hour\n                [ngForOf]=\"_hourList\"\n                let-i=\"index\">\n                 <li\n                   [ngClass]=\"_hour.name\"\n                   *ngIf=\"!(nzHideDisabledOptions&&_hour.disabled)\"\n                   [class.ant-time-picker-panel-select-option-selected]=\"_hour.index===_selectedHour\"\n                   [class.ant-time-picker-panel-select-option-disabled]=\"_hour.disabled\"\n                   (click)=\"_selectHour(hourListInstance,_hour.index,_hour.disabled)\">\n                   {{_hour.name}}\n                 </li>\n              </ng-template>\n            </ul>\n          </div>\n          <div\n            class=\"ant-calendar-time-picker-select\"\n            #minuteListInstance\n            *ngIf=\"_showMinute\">\n            <ul>\n              <ng-template\n                ngFor\n                let-_minute\n                [ngForOf]=\"_minuteList\"\n                let-i=\"index\">\n                 <li\n                   [ngClass]=\"_minute.name\"\n                   *ngIf=\"!(nzHideDisabledOptions&&_minute.disabled)\"\n                   [class.ant-time-picker-panel-select-option-selected]=\"_minute.index===_selectedMinute\"\n                   [class.ant-time-picker-panel-select-option-disabled]=\"_minute.disabled\"\n                   (click)=\"_selectMinute(minuteListInstance,_minute.index,_minute.disabled)\">\n                   {{_minute.name}}\n                 </li>\n              </ng-template>\n            </ul>\n          </div>\n          <div\n            class=\"ant-calendar-time-picker-select\"\n            #secondListInstance\n            *ngIf=\"_showSecond\">\n            <ul>\n              <ng-template\n                ngFor\n                let-_second\n                [ngForOf]=\"_secondList\"\n                let-i=\"index\">\n                 <li\n                   [ngClass]=\"_second.name\"\n                   *ngIf=\"!(nzHideDisabledOptions&&_second.disabled)\"\n                   [class.ant-time-picker-panel-select-option-selected]=\"_second.index===_selectedSecond\"\n                   [class.ant-time-picker-panel-select-option-disabled]=\"_second.disabled\"\n                   (click)=\"_selectSecond(secondListInstance,_second.index,_second.disabled)\">\n                   {{_second.name}}\n                 </li>\n              </ng-template>\n            </ul>\n          </div>\n        </div>\n      </div>\n      </div>\n    </span>",
                animations: [
                    DropDownAnimation
                ],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return NzTimePickerInnerComponent; }),
                        multi: true
                    }
                ],
                styles: [
                    "/* stylelint-disable at-rule-empty-line-before,at-rule-name-space-after,at-rule-no-unknown */\n/* stylelint-disable declaration-bang-space-before */\n/* stylelint-disable declaration-bang-space-before */\n.ant-time-picker-panel {\n  z-index: 1050;\n  position: absolute;\n}\n.ant-time-picker-panel-inner {\n  position: relative;\n  outline: none;\n  list-style: none;\n  font-size: 12px;\n  text-align: left;\n  background-color: #fff;\n  border-radius: 4px;\n  box-shadow: 0 1px 6px rgba(0, 0, 0, 0.2);\n  background-clip: padding-box;\n  line-height: 1.5;\n  overflow: hidden;\n  left: -2px;\n}\n.ant-time-picker-panel-input {\n  margin: 0;\n  padding: 0;\n  border: 0;\n  width: 100%;\n  cursor: auto;\n  line-height: 1.5;\n  outline: 0;\n}\n.ant-time-picker-panel-input::-moz-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n  opacity: 1;\n}\n.ant-time-picker-panel-input:-ms-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-panel-input::-webkit-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-panel-input-wrap {\n  box-sizing: border-box;\n  position: relative;\n  padding: 6px;\n  border-bottom: 1px solid #e9e9e9;\n}\n.ant-time-picker-panel-input-invalid {\n  border-color: red;\n}\n.ant-time-picker-panel-clear-btn {\n  position: absolute;\n  right: 5px;\n  cursor: pointer;\n  overflow: hidden;\n  width: 20px;\n  height: 20px;\n  text-align: center;\n  line-height: 20px;\n  top: 5px;\n  margin: 0;\n}\n.ant-time-picker-panel-clear-btn:after {\n  font-size: 12px;\n  color: rgba(0, 0, 0, 0.25);\n  display: inline-block;\n  line-height: 1;\n  width: 20px;\n  transition: color 0.3s ease;\n  font-family: 'anticon';\n  text-rendering: optimizeLegibility;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  content: \"\\e62e\";\n}\n.ant-time-picker-panel-clear-btn:hover:after {\n  color: rgba(0, 0, 0, 0.43);\n}\n.ant-time-picker-panel-narrow .ant-time-picker-panel-input-wrap {\n  max-width: 112px;\n}\n.ant-time-picker-panel-select {\n  float: left;\n  font-size: 12px;\n  border-left: 1px solid #e9e9e9;\n  box-sizing: border-box;\n  width: 56px;\n  overflow: hidden;\n  position: relative;\n  max-height: 144px;\n}\n.ant-time-picker-panel-select:hover {\n  overflow-y: auto;\n}\n.ant-time-picker-panel-select:first-child {\n  border-left: 0;\n  margin-left: 0;\n}\n.ant-time-picker-panel-select:last-child {\n  border-right: 0;\n}\n.ant-time-picker-panel-select:only-child {\n  width: 100%;\n}\n.ant-time-picker-panel-select ul {\n  list-style: none;\n  box-sizing: border-box;\n  margin: 0;\n  padding: 0 0 120px;\n  width: 100%;\n}\n.ant-time-picker-panel-select li {\n  list-style: none;\n  box-sizing: content-box;\n  margin: 0;\n  padding: 0 0 0 8px;\n  width: 100%;\n  height: 24px;\n  line-height: 24px;\n  text-align: left;\n  cursor: pointer;\n  user-select: none;\n  transition: background 0.3s;\n}\n.ant-time-picker-panel-select li:hover {\n  background: #ecf6fd;\n}\nli.ant-time-picker-panel-select-option-selected {\n  background: #f7f7f7;\n  font-weight: bold;\n}\nli.ant-time-picker-panel-select-option-selected:hover {\n  background: #f7f7f7;\n}\nli.ant-time-picker-panel-select-option-disabled {\n  color: rgba(0, 0, 0, 0.25);\n}\nli.ant-time-picker-panel-select-option-disabled:hover {\n  background: transparent;\n  cursor: not-allowed;\n}\n.ant-time-picker-panel-combobox {\n  zoom: 1;\n}\n.ant-time-picker-panel-combobox:before,\n.ant-time-picker-panel-combobox:after {\n  content: \" \";\n  display: table;\n}\n.ant-time-picker-panel-combobox:after {\n  clear: both;\n  visibility: hidden;\n  font-size: 0;\n  height: 0;\n}\n.ant-time-picker-panel-addon {\n  padding: 8px;\n  border-top: 1px solid #e9e9e9;\n}\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-topRight,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-topRight {\n  animation-name: antSlideDownIn;\n}\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-bottomRight,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-bottomRight {\n  animation-name: antSlideUpIn;\n}\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-topRight {\n  animation-name: antSlideDownOut;\n}\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-bottomRight {\n  animation-name: antSlideUpOut;\n}\n.ant-time-picker {\n  position: relative;\n  display: inline-block;\n  outline: none;\n  font-size: 12px;\n  transition: opacity 0.3s ease;\n  width: 100px;\n}\n.ant-time-picker-input {\n  position: relative;\n  display: inline-block;\n  padding: 4px 7px;\n  width: 100%;\n  height: 28px;\n  cursor: text;\n  font-size: 12px;\n  line-height: 1.5;\n  color: rgba(0, 0, 0, 0.65);\n  background-color: #fff;\n  background-image: none;\n  border: 1px solid #d9d9d9;\n  border-radius: 4px;\n  transition: all .3s;\n}\n.ant-time-picker-input::-moz-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n  opacity: 1;\n}\n.ant-time-picker-input:-ms-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input::-webkit-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input:hover {\n  border-color: #49a9ee;\n}\n.ant-time-picker-input:focus {\n  border-color: #49a9ee;\n  outline: 0;\n  box-shadow: 0 0 0 2px rgba(16, 142, 233, 0.2);\n}\n.ant-time-picker-input-disabled {\n  background-color: #f7f7f7;\n  opacity: 1;\n  cursor: not-allowed;\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input-disabled:hover {\n  border-color: #e2e2e2;\n}\ntextarea.ant-time-picker-input {\n  max-width: 100%;\n  height: auto;\n  vertical-align: bottom;\n}\n.ant-time-picker-input-lg {\n  padding: 6px 7px;\n  height: 32px;\n}\n.ant-time-picker-input-sm {\n  padding: 1px 7px;\n  height: 22px;\n}\n.ant-time-picker-input[disabled] {\n  background-color: #f7f7f7;\n  opacity: 1;\n  cursor: not-allowed;\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input[disabled]:hover {\n  border-color: #e2e2e2;\n}\n.ant-time-picker-large .ant-time-picker-input {\n  padding: 6px 7px;\n  height: 32px;\n}\n.ant-time-picker-small .ant-time-picker-input {\n  padding: 1px 7px;\n  height: 22px;\n}\n.ant-time-picker-open {\n  opacity: 0;\n}\n.ant-time-picker-icon {\n  position: absolute;\n  user-select: none;\n  transition: all 0.3s cubic-bezier(0.645, 0.045, 0.355, 1);\n  width: 12px;\n  height: 12px;\n  line-height: 12px;\n  right: 8px;\n  color: rgba(0, 0, 0, 0.43);\n  top: 50%;\n  margin-top: -6px;\n}\n.ant-time-picker-icon:after {\n  content: \"\\e641\";\n  font-family: \"anticon\";\n  font-size: 12px;\n  color: rgba(0, 0, 0, 0.43);\n  display: block;\n  line-height: 1;\n}\n",
                    "/* stylelint-disable at-rule-empty-line-before,at-rule-name-space-after,at-rule-no-unknown */\n/* stylelint-disable declaration-bang-space-before */\n/* stylelint-disable declaration-bang-space-before */\n.ant-time-picker-panel {\n  z-index: 1050;\n  position: absolute;\n}\n.ant-time-picker-panel-inner {\n  position: relative;\n  outline: none;\n  list-style: none;\n  font-size: 12px;\n  text-align: left;\n  background-color: #fff;\n  border-radius: 4px;\n  box-shadow: 0 1px 6px rgba(0, 0, 0, 0.2);\n  background-clip: padding-box;\n  line-height: 1.5;\n  overflow: hidden;\n  left: -2px;\n}\n.ant-time-picker-panel-input {\n  margin: 0;\n  padding: 0;\n  border: 0;\n  width: 100%;\n  cursor: auto;\n  line-height: 1.5;\n  outline: 0;\n}\n.ant-time-picker-panel-input::-moz-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n  opacity: 1;\n}\n.ant-time-picker-panel-input:-ms-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-panel-input::-webkit-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-panel-input-wrap {\n  box-sizing: border-box;\n  position: relative;\n  padding: 6px;\n  border-bottom: 1px solid #e9e9e9;\n}\n.ant-time-picker-panel-input-invalid {\n  border-color: red;\n}\n.ant-time-picker-panel-clear-btn {\n  position: absolute;\n  right: 5px;\n  cursor: pointer;\n  overflow: hidden;\n  width: 20px;\n  height: 20px;\n  text-align: center;\n  line-height: 20px;\n  top: 5px;\n  margin: 0;\n}\n.ant-time-picker-panel-clear-btn:after {\n  font-size: 12px;\n  color: rgba(0, 0, 0, 0.25);\n  display: inline-block;\n  line-height: 1;\n  width: 20px;\n  transition: color 0.3s ease;\n  font-family: 'anticon';\n  text-rendering: optimizeLegibility;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n  content: \"\\e62e\";\n}\n.ant-time-picker-panel-clear-btn:hover:after {\n  color: rgba(0, 0, 0, 0.43);\n}\n.ant-time-picker-panel-narrow .ant-time-picker-panel-input-wrap {\n  max-width: 112px;\n}\n.ant-time-picker-panel-select {\n  float: left;\n  font-size: 12px;\n  border-left: 1px solid #e9e9e9;\n  box-sizing: border-box;\n  width: 56px;\n  overflow: hidden;\n  position: relative;\n  max-height: 144px;\n}\n.ant-time-picker-panel-select:hover {\n  overflow-y: auto;\n}\n.ant-time-picker-panel-select:first-child {\n  border-left: 0;\n  margin-left: 0;\n}\n.ant-time-picker-panel-select:last-child {\n  border-right: 0;\n}\n.ant-time-picker-panel-select:only-child {\n  width: 100%;\n}\n.ant-time-picker-panel-select ul {\n  list-style: none;\n  box-sizing: border-box;\n  margin: 0;\n  padding: 0 0 120px;\n  width: 100%;\n}\n.ant-time-picker-panel-select li {\n  list-style: none;\n  box-sizing: content-box;\n  margin: 0;\n  padding: 0 0 0 8px;\n  width: 100%;\n  height: 24px;\n  line-height: 24px;\n  text-align: left;\n  cursor: pointer;\n  user-select: none;\n  transition: background 0.3s;\n}\n.ant-time-picker-panel-select li:hover {\n  background: #ecf6fd;\n}\nli.ant-time-picker-panel-select-option-selected {\n  background: #f7f7f7;\n  font-weight: bold;\n}\nli.ant-time-picker-panel-select-option-selected:hover {\n  background: #f7f7f7;\n}\nli.ant-time-picker-panel-select-option-disabled {\n  color: rgba(0, 0, 0, 0.25);\n}\nli.ant-time-picker-panel-select-option-disabled:hover {\n  background: transparent;\n  cursor: not-allowed;\n}\n.ant-time-picker-panel-combobox {\n  zoom: 1;\n}\n.ant-time-picker-panel-combobox:before,\n.ant-time-picker-panel-combobox:after {\n  content: \" \";\n  display: table;\n}\n.ant-time-picker-panel-combobox:after {\n  clear: both;\n  visibility: hidden;\n  font-size: 0;\n  height: 0;\n}\n.ant-time-picker-panel-addon {\n  padding: 8px;\n  border-top: 1px solid #e9e9e9;\n}\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-topRight,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-topRight {\n  animation-name: antSlideDownIn;\n}\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-enter.slide-up-enter-active.ant-time-picker-panel-placement-bottomRight,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-appear.slide-up-appear-active.ant-time-picker-panel-placement-bottomRight {\n  animation-name: antSlideUpIn;\n}\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-topLeft,\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-topRight {\n  animation-name: antSlideDownOut;\n}\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-bottomLeft,\n.ant-time-picker-panel.slide-up-leave.slide-up-leave-active.ant-time-picker-panel-placement-bottomRight {\n  animation-name: antSlideUpOut;\n}\n.ant-time-picker {\n  position: relative;\n  display: inline-block;\n  outline: none;\n  font-size: 12px;\n  transition: opacity 0.3s ease;\n  width: 100px;\n}\n.ant-time-picker-input {\n  position: relative;\n  display: inline-block;\n  padding: 4px 7px;\n  width: 100%;\n  height: 28px;\n  cursor: text;\n  font-size: 12px;\n  line-height: 1.5;\n  color: rgba(0, 0, 0, 0.65);\n  background-color: #fff;\n  background-image: none;\n  border: 1px solid #d9d9d9;\n  border-radius: 4px;\n  transition: all .3s;\n}\n.ant-time-picker-input::-moz-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n  opacity: 1;\n}\n.ant-time-picker-input:-ms-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input::-webkit-input-placeholder {\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input:hover {\n  border-color: #49a9ee;\n}\n.ant-time-picker-input:focus {\n  border-color: #49a9ee;\n  outline: 0;\n  box-shadow: 0 0 0 2px rgba(16, 142, 233, 0.2);\n}\n.ant-time-picker-input-disabled {\n  background-color: #f7f7f7;\n  opacity: 1;\n  cursor: not-allowed;\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input-disabled:hover {\n  border-color: #e2e2e2;\n}\ntextarea.ant-time-picker-input {\n  max-width: 100%;\n  height: auto;\n  vertical-align: bottom;\n}\n.ant-time-picker-input-lg {\n  padding: 6px 7px;\n  height: 32px;\n}\n.ant-time-picker-input-sm {\n  padding: 1px 7px;\n  height: 22px;\n}\n.ant-time-picker-input[disabled] {\n  background-color: #f7f7f7;\n  opacity: 1;\n  cursor: not-allowed;\n  color: rgba(0, 0, 0, 0.25);\n}\n.ant-time-picker-input[disabled]:hover {\n  border-color: #e2e2e2;\n}\n.ant-time-picker-large .ant-time-picker-input {\n  padding: 6px 7px;\n  height: 32px;\n}\n.ant-time-picker-small .ant-time-picker-input {\n  padding: 1px 7px;\n  height: 22px;\n}\n.ant-time-picker-open {\n  opacity: 0;\n}\n.ant-time-picker-icon {\n  position: absolute;\n  user-select: none;\n  transition: all 0.3s cubic-bezier(0.645, 0.045, 0.355, 1);\n  width: 12px;\n  height: 12px;\n  line-height: 12px;\n  right: 8px;\n  color: rgba(0, 0, 0, 0.43);\n  top: 50%;\n  margin-top: -6px;\n}\n.ant-time-picker-icon:after {\n  content: \"\\e641\";\n  font-family: \"anticon\";\n  font-size: 12px;\n  color: rgba(0, 0, 0, 0.43);\n  display: block;\n  line-height: 1;\n}\n.ant-time-picker-panel {\n  position: relative;\n  left: 0;\n}\n.ant-time-picker-panel.top {\n  bottom: -8px;\n}\n.ant-time-picker-panel.bottom {\n  top: -2px;\n}\n"
                ]
            },] },
];
/** @nocollapse */
NzTimePickerInnerComponent.ctorParameters = function () { return [
    { type: ChangeDetectorRef, },
]; };
NzTimePickerInnerComponent.propDecorators = {
    '_hourListInstance': [{ type: ViewChild, args: ['hourListInstance',] },],
    '_minuteListInstance': [{ type: ViewChild, args: ['minuteListInstance',] },],
    '_inputTimeInstance': [{ type: ViewChild, args: ['inputTimeInstance',] },],
    '_secondListInstance': [{ type: ViewChild, args: ['secondListInstance',] },],
    'nzHideDisabledOptions': [{ type: Input },],
    'nzPlaceHolder': [{ type: Input },],
    'nzSize': [{ type: Input },],
    'nzDisabledHours': [{ type: Input },],
    'nzDisabledMinutes': [{ type: Input },],
    'nzDisabledSeconds': [{ type: Input },],
    'nzDisabled': [{ type: Input },],
    'nzFormat': [{ type: Input },],
};
